pub struct Profile {
pub meta: Option<ProfileMeta>,
pub network: Option<NetworkConfig>,
pub filesystem: Option<FilesystemConfig>,
pub env: Option<EnvConfig>,
}Fields
meta: Option<ProfileMeta>network: Option<NetworkConfig>filesystem: Option<FilesystemConfig>env: Option<EnvConfig>Implementations
Sourceimpl Profile
impl Profile
Sourcepub fn merge(&mut self, other: &Profile)
pub fn merge(&mut self, other: &Profile)
Merge another profile on top of this one (union semantics).
Sourcepub fn merge_restrictive(&mut self, other: &Profile)
pub fn merge_restrictive(&mut self, other: &Profile)
Merge another profile using restrictive-only semantics. Can only ADD restrictions (more deny_read, more scrub patterns). Cannot ADD permissions (network.allow, allow_write, env.pass are IGNORED). Used for project configs (safe-shell.toml) and global configs to prevent a malicious repo from relaxing the sandbox.